@@ -74,7 +74,7 @@ static void gff_load_outline (GnomeFontFace *face, gint glyph);
 
 static void gf_pso_print_sized (GnomeFontPsObject *pso, const guchar *text, gint size);
 static void gf_pso_sprintf (GnomeFontPsObject * pso, 
-			    const gchar * format, ...);
+			    const gchar * format, ...) G_GNUC_PRINTF (2, 3);
 
 static void gnome_font_face_ps_embed_ensure_size (GnomeFontPsObject * pso, gint size);
 
@@ -491,6 +491,14 @@ gnome_font_face_get_glyph_stdkerning (GnomeFontFace *face, gint glyph0, gint gly
 const guchar *
 gnome_font_face_get_sample (GnomeFontFace * face)
 {
+	/* xgettext: Notice that this sentence contains every letter
+	 * of the English alphabet. This is a special sentence, called
+	 * a 'Pangram' (see: http://en.wikipedia.org/wiki/Pangram).
+	 * This sentence is used to demonstrate in a nice way how well
+	 * a font in your language looks. It's an improvement from having
+	 * just the alphabet of a language. 
+	 * Therefore, add a short sentence here in your language that 
+	 * demonstrates the letters of your alphabet. */
 	return _("The quick brown fox jumps over the lazy dog.");
 }
 
@@ -1613,7 +1621,11 @@ gnome_font_face_is_italic (GnomeFontFace * face)
 		e = face->entry;
 	}
 
+#ifdef G_OS_WIN32
+	return (e->italic_angle > 0 ? TRUE : FALSE);
+#else
 	return (e->italic_angle < 0 ? TRUE : FALSE);
+#endif
 }
 
 gboolean
