@@ -77,7 +77,7 @@ typedef struct {
 enum {
 	GSTATE_PEN,
 	GSTATE_BRUSH,
-	GSTATE_CLIPRGN,
+	GSTATE_CLIPRGN
 };
 
 static void gnome_print_gdi_class_init (GnomePrintGdiClass *klass);
